@@ -7,8 +7,7 @@ from numpy.random import Generator, default_rng
 from numgraph.utils import remove_self_loops, to_undirected, coalesce
 
 
-def erdos_renyi(num_nodes: int, prob: float, directed: bool = False,
-                weighted: bool = True, rng: Optional[Generator] = None) -> NDArray:
+def erdos_renyi(num_nodes: int, prob: float, directed: bool = False, rng: Optional[Generator] = None) -> NDArray:
     """
     Returns a random graph, also known as an Erdos-Renyi graph or a binomial graph.
     The model chooses each of the possible edges with a defined probability.
